@@ -9,14 +9,13 @@ import signal
 from multiprocessing import Pool, cpu_count
 from multiprocessing.pool import AsyncResult
 from pathlib import Path
-from typing import Dict, List, NamedTuple, Optional, Tuple, Union
+from typing import Dict, List, Match, NamedTuple, Optional, Pattern, Tuple, Union
 
 import matplotlib.pyplot as plt
 import numpy as np
 import pandas as pd
 import plotly.graph_objects as go
 import pysam
-
 from numpy.typing import ArrayLike
 from scipy import stats
 from tqdm.auto import tqdm
@@ -52,7 +51,7 @@ class BamOutput:
         self.values: Dict[str, str] = {}
         """Dict[str, str]: dictionary of reads at a given position"""
 
-        self.positions: pd.Index = self._run_sam_and_extract_df(sam_directory)
+        self.positions: List[str] = self._run_sam_and_extract_df(sam_directory)
         """"pd.Index: index of genomic positions in the bam file."""
 
         self.genome_values: Dict[str, str] = {}
@@ -60,7 +59,7 @@ class BamOutput:
 
         self._genome_parsing(genome_string)
 
-    def _run_sam_and_extract_df(self, sams: Path) -> pd.Index:
+    def _run_sam_and_extract_df(self, sams: Path) -> List[str]:
         """Process samfiles, pulling out sequence and position data
         and writing to folders/files.
 
@@ -68,7 +67,7 @@ class BamOutput:
             sams (Path): path to a samfile
 
         Returns:
-            pd.Index: list of unique positions in the samfile
+            List[str]: list of unique positions in the samfile
         """
 
         # Grab the promoter region of interest
@@ -96,7 +95,7 @@ class BamOutput:
 
         self._write_bam_output(df2.index.unique(), df3)
 
-        return df2.index.unique().tolist()
+        return df2.index.unique().astype(str).tolist()  # type: ignore
 
     def _write_bam_output(self, positions: pd.Index, df: pd.Series) -> None:
         """Extract alignments from sequencing reads and output text strings
@@ -174,7 +173,9 @@ class QumaResult:
         self._read_files: List[str] = read_files
         self._genomic_files: List[str] = genomic_files
         self._positions: List[str] = positions
-        self._raw_quma: List[str] = []
+        self.quma_output: List[quma.Quma] = []
+        """List[quma.Quma]: list of Quma result objects."""
+
         self.values: pd.DataFrame = self._pool_processing()
         """pd.DataFrame: dataframe of quma methylation analysis values."""
 
@@ -210,7 +211,7 @@ class QumaResult:
         # Set up a holding data frame from all the data
         holding_df: pd.DataFrame = pd.DataFrame()
 
-        returns: List[AsyncResult] = []
+        returns: List[AsyncResult[Tuple[pd.DataFrame, quma.Quma]]] = []
         with Pool(NUM_THREADS, self._init_worker) as pool:
 
             for position, read, genomic in zip(
@@ -226,10 +227,10 @@ class QumaResult:
             results = [result.get() for result in returns]
 
         # Add to excel file
-        for each in results:
+        for int_df, quma_obj in results:
             try:
-                holding_df = pd.concat([holding_df, each[0]], axis=1)
-                self._raw_quma.append(each[1])
+                holding_df = pd.concat([holding_df, int_df], axis=1)
+                self.quma_output.append(quma_obj)
             except (AttributeError, KeyError):  # pragma: no cover
                 pass
 
@@ -244,7 +245,7 @@ class QumaResult:
 
     def _thread_worker(
         self, genomic_contents: str, read_contents: str, position: str
-    ) -> Tuple[pd.DataFrame, str]:
+    ) -> Tuple[pd.DataFrame, quma.Quma]:
         """Queue worker for quma functions.
 
         Args:
@@ -253,18 +254,18 @@ class QumaResult:
             position(str): position of reads
 
         Returns:
-            Tuple[pd.DataFrame, str]: dataframe of quma results and raw quma results
+            Tuple[pd.DataFrame, quma.Quma]: dataframe of quma results and raw quma objs
         """
 
-        quma_result: str = self._access_quma(genomic_contents, read_contents)
+        quma_obj: quma.Quma = self._access_quma(genomic_contents, read_contents)
 
-        processed_quma: List[str] = self._process_raw_quma(quma_result)
+        processed_quma: List[str] = self._process_raw_quma(quma_obj.values)
         # Next, add this readname to the holding data frame
         int_df: pd.DataFrame = pd.DataFrame({position: processed_quma})
-        return int_df, quma_result
+        return int_df, quma_obj
 
     @staticmethod
-    def _access_quma(genomic_contents: str, read_contents: str) -> str:
+    def _access_quma(genomic_contents: str, read_contents: str) -> quma.Quma:
         """Helper function to run internal QUMA tool.
 
         Args:
@@ -272,12 +273,10 @@ class QumaResult:
             read_contents (str): query sequence
 
         Returns:
-            str: output from quma command
+            quma.Quma: quma object
         """
 
-        result = quma.Quma(genomic_contents, read_contents).values
-
-        return result
+        return quma.Quma(genomic_contents, read_contents)
 
 
 ##################################################################################
@@ -370,10 +369,14 @@ class GenomicPositionData:
         for name, bam_result in tqdm(
             self._bam_output.items(), desc="Process methylation"
         ):
-            # cell_line_name: str = Path(name).name.split("_")[1]
-            cell_line_name: str = re.match(
+            match: Optional[Match[str]] = re.match(
                 self.config.fname_pattern, Path(name).name
-            ).group(1)
+            )
+            cell_line_name: str
+            if isinstance(match, Match):
+                cell_line_name = match.group(1)
+            else:
+                cell_line_name = Path(name).name
 
             read_files: List[str] = [each for each in bam_result.values.values()]
             genomic_files: List[str] = [
@@ -425,7 +428,7 @@ class GenomicPositionData:
         """
 
         with open(filename, "rb") as input_file:
-            data = pickle.load(input_file)  # nosec
+            data: GenomicPositionData = pickle.load(input_file)  # nosec
 
         return data
 
@@ -528,7 +531,7 @@ class GenomicPositionData:
         values_list: List[float] = []
         # Check if this cell line has that position
         df: pd.DataFrame = self.quma_results[key].values
-        if pos in df.columns:  # type: ignore[union-attr]
+        if pos in df.columns:
 
             values_to_check: List[str] = self._get_str_values(df, pos)
             for value in values_to_check:
@@ -552,7 +555,7 @@ class GenomicPositionData:
         Returns:
             List[str]: list of values
         """
-        return df.loc[:, pos].dropna().astype(str)  # type: ignore[union-attr]
+        return df.loc[:, pos].dropna().astype(str).tolist()  # type: ignore
 
     @staticmethod
     def _find_diffs(means_df: pd.DataFrame, modes_df: pd.DataFrame) -> pd.DataFrame:
@@ -873,8 +876,11 @@ def configure(
     if not test_dir:
         test_dir = "test"
 
+    fname_pattern_compiled: Pattern[str]
     if not fname_pattern:
-        fname_pattern = r"^[a-zA-Z]+_([a-zA-Z0-9]+)_.+bam$"
+        fname_pattern_compiled = re.compile(r"^[a-zA-Z]+_([a-zA-Z0-9]+)_.+bam$")
+    else:
+        fname_pattern_compiled = re.compile(fname_pattern)
 
     if not viz_backend:
         viz_backend = "plotly"
@@ -892,7 +898,7 @@ def configure(
         chromosome=chrom,
         offset=offset,
         viz_backend=viz_backend,
-        fname_pattern=fname_pattern,
+        fname_pattern=fname_pattern_compiled,
     )
 
     return config
