@@ -10,9 +10,10 @@
 import re
 from dataclasses import dataclass
 from io import StringIO
-from typing import Dict, List, Tuple, Optional
-from Bio.Align import substitution_matrices
+from typing import Dict, List, Optional, Tuple
+
 from Bio import Align
+from Bio.Align import substitution_matrices
 
 # import logging
 
@@ -102,11 +103,12 @@ class Quma:
 
         _gfilepF: str = self._fasta_make(self._gseq, "genomeF")
 
-        self._raw_data: List[Reference] = self._process_fasta_output(
+        self.data: List[Reference] = self._process_fasta_output(
             self._qseq, "queryF", "queryR", _gfilepF
         )
+        """QUMA Output in object form."""
 
-        self.values: str = self._format_output(self._gseq, self._raw_data)
+        self.values: str = self._format_output(self._gseq, self.data)
         """QUMA output values in tabular form."""
 
     def _parse_genome(self) -> str:
@@ -401,7 +403,7 @@ class Quma:
             q_substring = q_matches[left_start_index:-right_end_index]
             g_substring = g_matches[left_start_index:-right_end_index]
 
-        return (q_substring, g_substring)
+        return (g_substring, q_substring)  # was flipped!
 
     def _align_seq_and_generate_stats(self, gfile: str, qfile: str) -> Result:
         """Run pairwise sequence alignment.
@@ -491,7 +493,7 @@ class Quma:
                     result.val += qAli[ni]
 
                 i = ni + 1
-            else:
+            else:  # pragma: no cover
                 break
 
         # kludge:
