@@ -3,36 +3,36 @@
 
 # Testing
 import base64
-import pytest
 import unittest.mock as mock
+from pathlib import Path
 
-# import os
-
-from .inputs import (
-    EXPECTED_INTERMEDIATE_DIFFS,
-    SAMPLE_BAM,
-    SAMPLE_BAI,
-    TEST_PROM_FILE,
-    EXPECTED_BAM_OUTPUT_POSITIONS,
-    EXPECTED_BAM_OUTPUT_VALUES,
-    EXPECTED_INTERMEDIATE_INDIVIDUAL_DATA,
-    EXPECTED_BAM_OUTPUT_GENOME_VALUES,
-    EXPECTED_STACKED_BAM,
-    EXPECTED_WRITE_DF_OUTPUT,
-    INPUT_READ_FILE,
-    EXPECTED_MEANS,
-    EXPECTED_RAW_QUMA,
-)
+import numpy as np
 
 # Required libraries for test data
 import pandas as pd
-
-import numpy as np
-from pathlib import Path
+import pytest
 
 # Module to test
 from pyllelic import pyllelic
 
+from .inputs import (
+    EXPECTED_BAM_OUTPUT_GENOME_VALUES,
+    EXPECTED_BAM_OUTPUT_POSITIONS,
+    EXPECTED_BAM_OUTPUT_VALUES,
+    EXPECTED_INTERMEDIATE_DIFFS,
+    EXPECTED_INTERMEDIATE_INDIVIDUAL_DATA,
+    EXPECTED_MEANS,
+    EXPECTED_QUMA_VALUES,
+    EXPECTED_STACKED_BAM,
+    EXPECTED_WRITE_DF_OUTPUT,
+    INPUT_READ_FILE,
+    SAMPLE_BAI,
+    SAMPLE_BAM,
+    TEST_PROM_FILE,
+)
+
+# import os
+
 
 # Helper methods
 @pytest.fixture(scope="session")
@@ -246,11 +246,11 @@ class Test_QumaOutput:
         EXPECTED_QUMA_VALUES = pd.DataFrame.from_dict(
             {
                 "1293588": {
-                    0: "G11-1",
-                    1: "G11-1",
-                    2: "G11-1",
-                    3: "G11-1",
-                    4: "G11-1",
+                    0: "111",
+                    1: "111",
+                    2: "111",
+                    3: "111",
+                    4: "111",
                     5: "1111",
                 }
             }
@@ -278,11 +278,11 @@ class Test_QumaOutput:
         EXPECTED_RESULTS = pd.DataFrame.from_dict(
             {
                 "1293588": {
-                    0: "G11-1",
-                    1: "G11-1",
-                    2: "G11-1",
-                    3: "G11-1",
-                    4: "G11-1",
+                    0: "111",
+                    1: "111",
+                    2: "111",
+                    3: "111",
+                    4: "111",
                     5: "1111",
                 }
             }
@@ -309,7 +309,7 @@ class Test_QumaOutput:
         actual = quma_output._thread_worker(TEST_GSEQ, TEST_QSEQ, TEST_READ_NAME)
 
         pd.testing.assert_frame_equal(actual[0], EXPECTED)
-        assert actual[1] == EXPECTED_RAW_QUMA
+        assert actual[1].values == EXPECTED_QUMA_VALUES
 
     def test_access_quma(self, set_up_quma_output):
         quma_output = set_up_quma_output
@@ -317,7 +317,7 @@ class Test_QumaOutput:
         TEST_QSEQ = ">query1\nATCGTAGTCGA\n>query2\nATCGATAGCATT"
 
         actual = quma_output._access_quma(TEST_GSEQ, TEST_QSEQ)
-        assert EXPECTED_RAW_QUMA == actual
+        assert actual.values == EXPECTED_QUMA_VALUES
 
 
 class Test_GenomicPositionData:
@@ -490,14 +490,14 @@ class Test_GenomicPositionData:
             {
                 "cellLine": {0: "test"},
                 "position": {0: "1295321"},
-                "ad_stat": {0: 15.372825521573787},
+                "ad_stat": {0: 13.510575364459704},
                 "p_crit": {0: 1.009},
-                "diff": {0: -0.024390243902439046},
+                "diff": {0: -0.04878048780487809},
                 "raw": {
                     0: [
                         0.0,
-                        1.0,
-                        1.0,
+                        0.5,
+                        0.5,
                         1.0,
                         1.0,
                         1.0,
